==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/bedrockfoundation/kotlin/outputs/GetModelResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.bedrockfoundation.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * A collection of values returned by getModel.
 * @property customizationsSupporteds Customizations that the model supports.
 * @property id
 * @property inferenceTypesSupporteds Inference types that the model supports.
 * @property inputModalities Input modalities that the model supports.
 * @property modelArn Model ARN.
 * @property modelId
 * @property modelName Model name.
 * @property outputModalities Output modalities that the model supports.
 * @property providerName Model provider name.
 * @property responseStreamingSupported Indicates whether the model supports streaming.
 */
public data class GetModelResult(
    public val customizationsSupporteds: List<String>,
    public val id: String,
    public val inferenceTypesSupporteds: List<String>,
    public val inputModalities: List<String>,
    public val modelArn: String,
    public val modelId: String,
    public val modelName: String,
    public val outputModalities: List<String>,
    public val providerName: String,
    public val responseStreamingSupported: Boolean,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.bedrockfoundation.outputs.GetModelResult):
            GetModelResult = GetModelResult(
            customizationsSupporteds = javaType.customizationsSupporteds().map({ args0 -> args0 }),
            id = javaType.id(),
            inferenceTypesSupporteds = javaType.inferenceTypesSupporteds().map({ args0 -> args0 }),
            inputModalities = javaType.inputModalities().map({ args0 -> args0 }),
            modelArn = javaType.modelArn(),
            modelId = javaType.modelId(),
            modelName = javaType.modelName(),
            outputModalities = javaType.outputModalities().map({ args0 -> args0 }),
            providerName = javaType.providerName(),
            responseStreamingSupported = javaType.responseStreamingSupported(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/bedrockfoundation/kotlin/outputs/GetModelResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.bedrockfoundation.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * A collection of values returned by getModel.
 * @property customizationsSupporteds Customizations that the model supports.
 * @property id
 * @property inferenceTypesSupporteds Inference types that the model supports.
 * @property inputModalities Input modalities that the model supports.
 * @property modelArn Model ARN.
 * @property modelId
 * @property modelName Model name.
 * @property outputModalities Output modalities that the model supports.
 * @property providerName Model provider name.
 * @property responseStreamingSupported Indicates whether the model supports streaming.
 */
public data class GetModelResult(
    public val customizationsSupporteds: List<String>,
    public val id: String,
    public val inferenceTypesSupporteds: List<String>,
    public val inputModalities: List<String>,
    public val modelArn: String,
    public val modelId: String,
    public val modelName: String,
    public val outputModalities: List<String>,
    public val providerName: String,
    public val responseStreamingSupported: Boolean,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.bedrockfoundation.outputs.GetModelResult): GetModelResult = GetModelResult(
            customizationsSupporteds = javaType.customizationsSupporteds().map({ args0 -> args0 }),
            id = javaType.id(),
            inferenceTypesSupporteds = javaType.inferenceTypesSupporteds().map({ args0 -> args0 }),
            inputModalities = javaType.inputModalities().map({ args0 -> args0 }),
            modelArn = javaType.modelArn(),
            modelId = javaType.modelId(),
            modelName = javaType.modelName(),
            outputModalities = javaType.outputModalities().map({ args0 -> args0 }),
            providerName = javaType.providerName(),
            responseStreamingSupported = javaType.responseStreamingSupported(),
        )
    }
}
